<?php

namespace App\Models;

use Illuminate\Contracts\Auth\MustVerifyEmail;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Notifications\Notifiable;

class User extends Authenticatable
{
    use HasFactory, Notifiable;

    protected $appends = ['tips_total', 'memes_total'];

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable = [
        'name',
        'email',
        'address',
        'password',
    ];

    /**
     * The attributes that should be hidden for arrays.
     *
     * @var array
     */
    protected $hidden = [
        'password',
        'remember_token',
    ];

    /**
     * The attributes that should be cast to native types.
     *
     * @var array
     */
    protected $casts = [
        'email_verified_at' => 'datetime',
    ];

    public function memes()
    {
        return $this->hasMany(Meme::class)->orderByDesc('created_at');
    }

    public function tips()
    {
        return $this->hasManyThrough(Tip::class, Meme::class, 'user_id');
    }

    public function getMemesTotalAttribute()
    {
        return $this->memes->count();
    }

    public function getTipsTotalAttribute()
    {
        return $this->tips->where('is_deposit', 1)->sum('amount_formatted');
    }

}
